@@ -7,6 +7,19 @@ setClass("TDR",
              if (length(object@time) != length(object@depth)) {
                  return("depth and time must have equal lengths")
              }
+             time.diffs <- diff(unclass(object@time))
+             if (any(time.diffs < 0)) {
+                 return("time stamps must be in increasing order")
+             }
+             ## if (any(time.diffs == 0)) {
+             ##     return("time stamps must not contain duplicate values")
+             ## }
+             ccDataN <- nrow(object@concurrentData)
+             if (ccDataN > 0 && ccDataN != length(object@time)) {
+                 mes <- paste("concurrentData must have the same number of rows",
+                              "as there are time stamps")
+                 return(mes)
+             }
              if (!slot(object, "dtime")) return("dtime cannot be missing")
              return(TRUE)
          })
